@@ -2,12 +2,14 @@
 import sys
 import unittest
 
+import pytest
 import six
 
 import fiona
 
 FIXME_WINDOWS = sys.platform.startswith('win')
 
+
 class ReadingTest(unittest.TestCase):
 
     def setUp(self):
@@ -24,20 +26,18 @@ class ReadingTest(unittest.TestCase):
             strbuf = src.read()
         self.assertRaises(ValueError, fiona.BytesCollection, strbuf)
 
-    @unittest.skipIf(FIXME_WINDOWS, 
+    @unittest.skipIf(FIXME_WINDOWS,
                      reason="FIXME on Windows. Please look into why this test is not working.")
     def test_open_repr(self):
         # I'm skipping checking the name of the virtual file as it produced by uuid.
         self.assertTrue(repr(self.c).startswith("<open BytesCollection '/vsimem/"))
-        self.assertTrue(repr(self.c).endswith(":OGRGeoJSON', mode 'r' at %s>" % hex(id(self.c))))
 
-    @unittest.skipIf(FIXME_WINDOWS, 
+    @unittest.skipIf(FIXME_WINDOWS,
                      reason="FIXME on Windows. Please look into why this test is not working.")
     def test_closed_repr(self):
         # I'm skipping checking the name of the virtual file as it produced by uuid.
         self.c.close()
         self.assertTrue(repr(self.c).startswith("<closed BytesCollection '/vsimem/"))
-        self.assertTrue(repr(self.c).endswith(":OGRGeoJSON', mode 'r' at %s>" % hex(id(self.c))))
 
     def test_path(self):
         self.assertEqual(self.c.path, self.c.virtual_file)
@@ -51,12 +51,12 @@ class ReadingTest(unittest.TestCase):
         self.assertTrue(self.c.bytesbuf is None)
 
     def test_name(self):
-        self.assertEqual(self.c.name, 'OGRGeoJSON')
+        self.assertTrue(len(self.c.name) > 0)
 
     def test_mode(self):
         self.assertEqual(self.c.mode, 'r')
 
-    @unittest.skipIf(FIXME_WINDOWS, 
+    @unittest.skipIf(FIXME_WINDOWS,
                      reason="FIXME on Windows. Please look into why this test is not working.")
     def test_collection(self):
         self.assertEqual(self.c.encoding, 'utf-8')
@@ -157,8 +157,8 @@ class ReadingTest(unittest.TestCase):
         self.assertEqual(f['properties']['STATE'], 'UT')
 
     def test_re_iter_list(self):
-        f = list(self.c)[0] # Run through iterator
-        f = list(self.c)[0] # Run through a new, reset iterator
+        f = list(self.c)[0]  # Run through iterator
+        f = list(self.c)[0]  # Run through a new, reset iterator
         self.assertEqual(f['id'], "0")
         self.assertEqual(f['properties']['STATE'], 'UT')
 
@@ -216,4 +216,30 @@ class FilterReadingTest(unittest.TestCase):
         self.assertEqual(len(results), 26)
 
 
+def test_zipped_bytes_collection():
+    with open('tests/data/coutwildrnp.zip', 'rb') as src:
+        zip_file_bytes = src.read()
 
+    with fiona.BytesCollection(zip_file_bytes) as col:
+        assert col.name == 'coutwildrnp'
+
+
+def test_grenada_bytes_geojson():
+    """Read grenada.geojson as BytesCollection.
+
+    grenada.geojson is an example of geojson that GDAL's GeoJSON
+    driver will fail to read successfully unless the file's extension
+    reflects its json'ness.
+    """
+    with open('tests/data/grenada.geojson', 'rb') as src:
+        bytes_grenada_geojson = src.read()
+    
+    # We expect an exception if the GeoJSON driver isn't specified.
+    with pytest.raises(fiona.errors.FionaValueError):
+        with fiona.BytesCollection(bytes_grenada_geojson) as col:
+            pass
+
+    # If told what driver to use, we should be good.
+    with fiona.BytesCollection(bytes_grenada_geojson, driver='GeoJSON') as col:        
+        assert len(col) == 1
+        
