@@ -10,7 +10,10 @@ import fiona
 from fiona.collection import supported_drivers
 from fiona.errors import FionaValueError, DriverError, SchemaError, CRSError
 
-logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
+
+# logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
+
+log = logging.getLogger(__name__)
 
 
 class ReadingTest(unittest.TestCase):
@@ -46,3 +49,24 @@ class WritingTest(unittest.TestCase):
         with fiona.open(path) as c:
             self.assertEqual(c.schema['geometry'], 'Unknown')
             self.assertEqual(len(c), 2)
+
+    def test_json_overwrite(self):
+        path = os.path.join(self.tempdir, 'foo.json')
+
+        with fiona.drivers(), fiona.open(path, 'w', 
+                driver='GeoJSON', 
+                schema={'geometry': 'Unknown', 'properties': [('title', 'str')]}) as c:
+            c.writerecords([{
+                'geometry': {'type': 'Point', 'coordinates': [0.0, 0.0]},
+                'properties': {'title': 'One'}}])
+            c.writerecords([{
+                'geometry': {'type': 'MultiPoint', 'coordinates': [[0.0, 0.0]]},
+                'properties': {'title': 'Two'}}])
+
+        # Overwrite should raise DriverIOError.
+        try:
+            with fiona.drivers(), fiona.open(path, 'w', driver='GeoJSON', 
+                    schema={'geometry': 'Unknown', 'properties': [('title', 'str')]}) as c:
+                pass
+        except IOError:
+            pass
