@@ -7,7 +7,7 @@ import fiona
 from fiona.errors import FionaValueError
 
 
-logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
+logging.basicConfig(stream=sys.stderr, level=logging.INFO)
 
 def test_read_fail():
     with pytest.raises(FionaValueError):
